@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 # -*- coding: utf-8 -*-
 # Copyright (c) 2000, Atlantis Scientific Inc. (www.atlsci.com)
 # Copyright (C) 2005  Gabriel Ebner <ge@gabrielebner.at>
@@ -50,6 +50,7 @@ def names_to_fileinfos(names):
 
     return file_infos
 
+
 # *****************************************************************************
 
 
@@ -144,10 +145,12 @@ class file_info(object):
         # compute target window in pixel coordinates.
         tw_xoff = int((tgw_ulx - t_geotransform[0]) / t_geotransform[1] + 0.1)
         tw_yoff = int((tgw_uly - t_geotransform[3]) / t_geotransform[5] + 0.1)
-        tw_xsize = int((tgw_lrx - t_geotransform[0]) / t_geotransform[1] + 0.5) \
-            - tw_xoff
-        tw_ysize = int((tgw_lry - t_geotransform[3]) / t_geotransform[5] + 0.5) \
-            - tw_yoff
+        tw_xsize = (
+            int((tgw_lrx - t_geotransform[0]) / t_geotransform[1] + 0.5) - tw_xoff
+        )
+        tw_ysize = (
+            int((tgw_lry - t_geotransform[3]) / t_geotransform[5] + 0.5) - tw_yoff
+        )
 
         if tw_xsize < 1 or tw_ysize < 1:
             return 1
@@ -155,41 +158,53 @@ class file_info(object):
         # Compute source window in pixel coordinates.
         sw_xoff = int((tgw_ulx - self.geotransform[0]) / self.geotransform[1])
         sw_yoff = int((tgw_uly - self.geotransform[3]) / self.geotransform[5])
-        sw_xsize = int((tgw_lrx - self.geotransform[0]) /
-                       self.geotransform[1] + 0.5) - sw_xoff
-        sw_ysize = int((tgw_lry - self.geotransform[3]) /
-                       self.geotransform[5] + 0.5) - sw_yoff
+        sw_xsize = (
+            int((tgw_lrx - self.geotransform[0]) / self.geotransform[1] + 0.5) - sw_xoff
+        )
+        sw_ysize = (
+            int((tgw_lry - self.geotransform[3]) / self.geotransform[5] + 0.5) - sw_yoff
+        )
 
         if sw_xsize < 1 or sw_ysize < 1:
             return 1
 
-        t_fh.write('\t\t<SimpleSource>\n')
-        t_fh.write(('\t\t\t<SourceFilename relativeToVRT="1">%s' +
-                    '</SourceFilename>\n') % self.filename)
-        t_fh.write('\t\t\t<SourceBand>%i</SourceBand>\n' % s_band)
+        t_fh.write("\t\t<SimpleSource>\n")
+        t_fh.write(
+            ('\t\t\t<SourceFilename relativeToVRT="1">%s' + "</SourceFilename>\n")
+            % self.filename
+        )
+        t_fh.write("\t\t\t<SourceBand>%i</SourceBand>\n" % s_band)
         data_type_name = gdal.GetDataTypeName(self.band_types[s_band])
         block_size_x, block_size_y = self.block_sizes[s_band]
-        t_fh.write('\t\t\t<SourceProperties RasterXSize="%i" RasterYSize="%i"'
-                   ' DataType="%s" BlockXSize="%i" BlockYSize="%i"/>\n'
-                   % (self.xsize, self.ysize, data_type_name, block_size_x, block_size_y))
-        t_fh.write('\t\t\t<SrcRect xOff="%i" yOff="%i" xSize="%i" ySize="%i"/>\n'
-                   % (sw_xoff, sw_yoff, sw_xsize, sw_ysize))
-        t_fh.write('\t\t\t<DstRect xOff="%i" yOff="%i" xSize="%i" ySize="%i"/>\n'
-                   % (tw_xoff, tw_yoff, tw_xsize, tw_ysize))
-        t_fh.write('\t\t</SimpleSource>\n')
+        t_fh.write(
+            '\t\t\t<SourceProperties RasterXSize="%i" RasterYSize="%i"'
+            ' DataType="%s" BlockXSize="%i" BlockYSize="%i"/>\n'
+            % (self.xsize, self.ysize, data_type_name, block_size_x, block_size_y)
+        )
+        t_fh.write(
+            '\t\t\t<SrcRect xOff="%i" yOff="%i" xSize="%i" ySize="%i"/>\n'
+            % (sw_xoff, sw_yoff, sw_xsize, sw_ysize)
+        )
+        t_fh.write(
+            '\t\t\t<DstRect xOff="%i" yOff="%i" xSize="%i" ySize="%i"/>\n'
+            % (tw_xoff, tw_yoff, tw_xsize, tw_ysize)
+        )
+        t_fh.write("\t\t</SimpleSource>\n")
+
 
 # =============================================================================
 
 
 def Usage():
-    print('Usage: gdal_vrtmerge.py [-o out_filename] [-separate] [-pct]')
-    print('           [-ul_lr ulx uly lrx lry] [-ot datatype] [-i input_file_list')
-    print('           | input_files]')
+    print("Usage: gdal_vrtmerge.py [-o out_filename] [-separate] [-pct]")
+    print("           [-ul_lr ulx uly lrx lry] [-ot datatype] [-i input_file_list")
+    print("           | input_files]")
+    return 2
 
 
-def main(argv):
+def main(argv=sys.argv):
     names = []
-    out_file = 'out.vrt'
+    out_file = "out.vrt"
 
     ulx = None
     psize_x = None
@@ -205,29 +220,28 @@ def main(argv):
     while i < len(argv):
         arg = argv[i]
 
-        if arg == '-o':
+        if arg == "-o":
             i = i + 1
             out_file = argv[i]
 
-        elif arg == '-i':
+        elif arg == "-i":
             i = i + 1
             in_file_list = open(argv[i])
             names.extend(in_file_list.read().split())
 
-        elif arg == '-separate':
+        elif arg == "-separate":
             separate = True
 
-        elif arg == '-ul_lr':
+        elif arg == "-ul_lr":
             ulx = float(argv[i + 1])
             uly = float(argv[i + 2])
             lrx = float(argv[i + 3])
             lry = float(argv[i + 4])
             i = i + 4
 
-        elif arg[:1] == '-':
-            print('Unrecognized command option: ', arg)
-            Usage()
-            return 1
+        elif arg[:1] == "-":
+            print("Unrecognized command option: ", arg)
+            return Usage()
 
         else:
             names.append(arg)
@@ -235,14 +249,13 @@ def main(argv):
         i = i + 1
 
     if not names:
-        print('No input files selected.')
-        Usage()
-        return 1
+        print("No input files selected.")
+        return Usage()
 
     # Collect information on all the source files.
     file_infos = names_to_fileinfos(names)
     if not file_infos:
-        print('Nothing to process, exiting.')
+        print("Nothing to process, exiting.")
         return 1
 
     if ulx is None:
@@ -265,8 +278,7 @@ def main(argv):
 
     for fi in file_infos:
         if fi.geotransform[1] != psize_x or fi.geotransform[5] != psize_y:
-            print("All files must have the same scale; %s does not"
-                  % fi.filename)
+            print("All files must have the same scale; %s does not" % fi.filename)
             return 1
 
         if fi.geotransform[2] != 0 or fi.geotransform[4] != 0:
@@ -274,8 +286,7 @@ def main(argv):
             return 1
 
         if fi.projection != projection:
-            print("All files must be in the same projection; %s is not"
-                  % fi.filename)
+            print("All files must be in the same projection; %s is not" % fi.filename)
             return 1
 
     geotransform = (ulx, psize_x, 0.0, uly, 0.0, psize_y)
@@ -288,61 +299,69 @@ def main(argv):
     else:
         bands = file_infos[0].bands
 
-    t_fh = open(out_file, 'w')
-    t_fh.write('<VRTDataset rasterXSize="%i" rasterYSize="%i">\n'
-               % (xsize, ysize))
-    t_fh.write('\t<GeoTransform>%24.16f, %24.16f, %24.16f, %24.16f, %24.16f, %24.16f</GeoTransform>\n'
-               % geotransform)
+    t_fh = open(out_file, "w")
+    t_fh.write('<VRTDataset rasterXSize="%i" rasterYSize="%i">\n' % (xsize, ysize))
+    t_fh.write(
+        "\t<GeoTransform>%24.16f, %24.16f, %24.16f, %24.16f, %24.16f, %24.16f</GeoTransform>\n"
+        % geotransform
+    )
 
     if projection:
-        t_fh.write('\t<SRS>%s</SRS>\n' % projection)
+        t_fh.write("\t<SRS>%s</SRS>\n" % projection)
 
     if separate:
         band_n = 0
         for fi in file_infos:
             band_n = band_n + 1
             if len(fi.band_types) != 2:
-                print('File %s has %d bands. Only first band will be taken '
-                      'into account' % (fi.filename, len(fi.band_types) - 1))
+                print(
+                    "File %s has %d bands. Only first band will be taken "
+                    "into account" % (fi.filename, len(fi.band_types) - 1)
+                )
             dataType = gdal.GetDataTypeName(fi.band_types[1])
 
-            t_fh.write('\t<VRTRasterBand dataType="%s" band="%i">\n'
-                       % (dataType, band_n))
-            t_fh.write('\t\t<ColorInterp>%s</ColorInterp>\n' %
-                       gdal.GetColorInterpretationName(fi.color_interps[1]))
+            t_fh.write(
+                '\t<VRTRasterBand dataType="%s" band="%i">\n' % (dataType, band_n)
+            )
+            t_fh.write(
+                "\t\t<ColorInterp>%s</ColorInterp>\n"
+                % gdal.GetColorInterpretationName(fi.color_interps[1])
+            )
             fi.write_source(t_fh, geotransform, xsize, ysize, 1)
-            t_fh.write('\t</VRTRasterBand>\n')
+            t_fh.write("\t</VRTRasterBand>\n")
     else:
         for band in range(1, bands + 1):
             dataType = gdal.GetDataTypeName(file_infos[0].band_types[band])
 
-            t_fh.write('\t<VRTRasterBand dataType="%s" band="%i">\n'
-                       % (dataType, band))
+            t_fh.write('\t<VRTRasterBand dataType="%s" band="%i">\n' % (dataType, band))
             if file_infos[0].nodata != [None]:
-                t_fh.write('\t\t<NoDataValue>%f</NoDataValue>\n' %
-                           file_infos[0].nodata[band])
-            t_fh.write('\t\t<ColorInterp>%s</ColorInterp>\n' %
-                       gdal.GetColorInterpretationName(
-                           file_infos[0].color_interps[band]))
+                t_fh.write(
+                    "\t\t<NoDataValue>%f</NoDataValue>\n" % file_infos[0].nodata[band]
+                )
+            t_fh.write(
+                "\t\t<ColorInterp>%s</ColorInterp>\n"
+                % gdal.GetColorInterpretationName(file_infos[0].color_interps[band])
+            )
 
             ct = file_infos[0].cts[band]
             if ct is not None:
-                t_fh.write('\t\t<ColorTable>\n')
+                t_fh.write("\t\t<ColorTable>\n")
                 for i in range(ct.GetCount()):
                     t_fh.write(
                         '\t\t\t<Entry c1="%i" c2="%i" c3="%i" c4="%i"/>\n'
-                        % ct.GetColorEntry(i))
-                t_fh.write('\t\t</ColorTable>\n')
+                        % ct.GetColorEntry(i)
+                    )
+                t_fh.write("\t\t</ColorTable>\n")
 
             for fi in file_infos:
                 fi.write_source(t_fh, geotransform, xsize, ysize, band)
 
-            t_fh.write('\t</VRTRasterBand>\n')
+            t_fh.write("\t</VRTRasterBand>\n")
 
-    t_fh.write('</VRTDataset>\n')
+    t_fh.write("</VRTDataset>\n")
 
     return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
