@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 # ******************************************************************************
 #  $Id$
 #
@@ -41,32 +41,32 @@ from osgeo import gdal
 def main(argv=sys.argv):
     if len(argv) < 3:
         print("Usage: gdalcopyproj.py source_file dest_file")
-        return 1
+        return 2
 
     inp = argv[1]
     dataset = gdal.Open(inp)
     if dataset is None:
-        print('Unable to open', inp, 'for reading')
+        print("Unable to open", inp, "for reading")
         return 1
 
     projection = dataset.GetProjection()
     geotransform = dataset.GetGeoTransform()
 
     if projection is None and geotransform is None:
-        print('No projection or geotransform found on file' + input)
+        print("No projection or geotransform found on file" + input)
         return 1
 
     output = argv[2]
     dataset2 = gdal.Open(output, gdal.GA_Update)
 
     if dataset2 is None:
-        print('Unable to open', output, 'for writing')
+        print("Unable to open", output, "for writing")
         return 1
 
     if geotransform is not None and geotransform != (0, 1, 0, 0, 0, 1):
         dataset2.SetGeoTransform(geotransform)
 
-    if projection is not None and projection != '':
+    if projection is not None and projection != "":
         dataset2.SetProjection(projection)
 
     gcp_count = dataset.GetGCPCount()
@@ -78,5 +78,5 @@ def main(argv=sys.argv):
     return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
