@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.10
 ###############################################################################
 # $Id$
 #
@@ -34,21 +34,22 @@
 
 
 import sys
+
 import numpy as np
 
 from osgeo import gdal
-gdal.TermProgress = gdal.TermProgress_nocb
 
+gdal.TermProgress = gdal.TermProgress_nocb
 
 
 # =============================================================================
 
 
 def Usage():
-    print('Usage: val_repl.py -innd in_nodata_value -outnd out_nodata_value')
-    print('                   [-of out_format] [-ot out_type] infile outfile')
-    print('')
-    return 1
+    print("Usage: val_repl.py -innd in_nodata_value -outnd out_nodata_value")
+    print("                   [-of out_format] [-ot out_type] infile outfile")
+    print("")
+    return 2
 
 
 def ParseType(typ):
@@ -63,7 +64,7 @@ def main(argv=sys.argv):
     outNoData = None
     infile = None
     outfile = None
-    driver_name = 'GTiff'
+    driver_name = "GTiff"
     typ = gdal.GDT_Byte
 
     # Parse command line arguments.
@@ -71,19 +72,19 @@ def main(argv=sys.argv):
     while i < len(argv):
         arg = argv[i]
 
-        if arg == '-innd':
+        if arg == "-innd":
             i = i + 1
             inNoData = float(argv[i])
 
-        elif arg == '-outnd':
+        elif arg == "-outnd":
             i = i + 1
             outNoData = float(argv[i])
 
-        elif arg == '-of':
+        elif arg == "-of":
             i = i + 1
             driver_name = argv[i]
 
-        elif arg == '-ot':
+        elif arg == "-ot":
             i = i + 1
             typ = ParseType(argv[i])
 
@@ -110,7 +111,13 @@ def main(argv=sys.argv):
     indataset = gdal.Open(infile, gdal.GA_ReadOnly)
 
     out_driver = gdal.GetDriverByName(driver_name)
-    outdataset = out_driver.Create(outfile, indataset.RasterXSize, indataset.RasterYSize, indataset.RasterCount, typ)
+    outdataset = out_driver.Create(
+        outfile,
+        indataset.RasterXSize,
+        indataset.RasterYSize,
+        indataset.RasterCount,
+        typ,
+    )
 
     gt = indataset.GetGeoTransform()
     if gt is not None and gt != (0.0, 1.0, 0.0, 0.0, 0.0, 1.0):
@@ -126,11 +133,10 @@ def main(argv=sys.argv):
 
         for i in range(inband.YSize - 1, -1, -1):
             scanline = inband.ReadAsArray(0, i, inband.XSize, 1, inband.XSize, 1)
-            scanline = np.choose(np.equal(scanline, inNoData),
-                                    (scanline, outNoData))
+            scanline = np.choose(np.equal(scanline, inNoData), (scanline, outNoData))
             outband.WriteArray(scanline, 0, i)
     return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
